==> jc-1.4.0.tar.gz: gnu/xml/dom/DomExtern.h <==
// public abstract class gnu.xml.dom.DomExtern

// class file dependencies
// @dep_class 927ff3b1d72554f gnu_xml_dom_DomExtern
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomExtern_H_
#define _JC_gnu_xml_dom_DomExtern_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomExtern$sub_refs	_jc_gnu_xml_dom_DomExtern$sub_refs;
typedef struct _jc_gnu_xml_dom_DomExtern$sub_nonrefs	_jc_gnu_xml_dom_DomExtern$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomExtern$refs	_jc_gnu_xml_dom_DomExtern$refs;
typedef struct _jc_gnu_xml_dom_DomExtern$nonrefs	_jc_gnu_xml_dom_DomExtern$nonrefs;
typedef struct _jc_gnu_xml_dom_DomExtern$object	_jc_gnu_xml_dom_DomExtern$object;

typedef const struct _jc_gnu_xml_dom_DomExtern$vmethods	_jc_gnu_xml_dom_DomExtern$vmethods;
typedef const struct _jc_gnu_xml_dom_DomExtern$vtable	_jc_gnu_xml_dom_DomExtern$vtable;
typedef const struct _jc_gnu_xml_dom_DomExtern$vtype	_jc_gnu_xml_dom_DomExtern$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomExtern$method$_init$5c725eae6735e210(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *, jshort, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getLocalName$eac3696fdfce5426(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getLocalName$eac3696fdfce5426;
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getNodeName$f5b11134ac79aed1;
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getSystemId$dfda7e64149e1929;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomExtern$vmethods {
	struct _jc_java_lang_String$object	*(*getLocalName$eac3696fdfce5426)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomExtern$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomExtern$vmethods	gnu_xml_dom_DomExtern;
};

// Vtype
struct _jc_gnu_xml_dom_DomExtern$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomExtern$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomExtern$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*publicId;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomExtern$refs {
    _jc_gnu_xml_dom_DomExtern$sub_refs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomExtern$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomExtern$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomExtern$sub_nonrefs	gnu_xml_dom_DomExtern;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomExtern$object {
	_jc_gnu_xml_dom_DomExtern$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomExtern$vtype	*vtype;
	_jc_gnu_xml_dom_DomExtern$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomExtern$vtype _jc_gnu_xml_dom_DomExtern$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomExtern, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomExtern$class_object;

#endif	/* _JC_gnu_xml_dom_DomExtern_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomExtern.h <==
// public abstract class gnu.xml.dom.DomExtern

// class file dependencies
// @dep_class 927ff3b1d72554f gnu_xml_dom_DomExtern
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomNode

#include "gnu/xml/dom/DomNode.h"

#ifndef _JC_gnu_xml_dom_DomExtern_H_
#define _JC_gnu_xml_dom_DomExtern_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomExtern$sub_refs	_jc_gnu_xml_dom_DomExtern$sub_refs;
typedef struct _jc_gnu_xml_dom_DomExtern$sub_nonrefs	_jc_gnu_xml_dom_DomExtern$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomExtern$refs	_jc_gnu_xml_dom_DomExtern$refs;
typedef struct _jc_gnu_xml_dom_DomExtern$nonrefs	_jc_gnu_xml_dom_DomExtern$nonrefs;
typedef struct _jc_gnu_xml_dom_DomExtern$object	_jc_gnu_xml_dom_DomExtern$object;

typedef const struct _jc_gnu_xml_dom_DomExtern$vmethods	_jc_gnu_xml_dom_DomExtern$vmethods;
typedef const struct _jc_gnu_xml_dom_DomExtern$vtable	_jc_gnu_xml_dom_DomExtern$vtable;
typedef const struct _jc_gnu_xml_dom_DomExtern$vtype	_jc_gnu_xml_dom_DomExtern$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomExtern$method$_init$5c725eae6735e210(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *, jshort, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getLocalName$eac3696fdfce5426(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomExtern$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getLocalName$eac3696fdfce5426;
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getNodeName$f5b11134ac79aed1;
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_dom_DomExtern$method_info$getSystemId$dfda7e64149e1929;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomExtern$vmethods {
	struct _jc_java_lang_String$object	*(*getLocalName$eac3696fdfce5426)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_dom_DomExtern$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomExtern$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomExtern$vmethods	gnu_xml_dom_DomExtern;
};

// Vtype
struct _jc_gnu_xml_dom_DomExtern$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomExtern$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomExtern$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*publicId;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomExtern$refs {
    _jc_gnu_xml_dom_DomExtern$sub_refs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomExtern$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomExtern$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomExtern$sub_nonrefs	gnu_xml_dom_DomExtern;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomExtern$object {
	_jc_gnu_xml_dom_DomExtern$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomExtern$vtype	*vtype;
	_jc_gnu_xml_dom_DomExtern$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomExtern$vtype _jc_gnu_xml_dom_DomExtern$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomExtern, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomExtern$class_object;

#endif	/* _JC_gnu_xml_dom_DomExtern_H_ */
